<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:dos="http://xml.di.uminho.pt/PED2004/dossier" xmlns:bib="http://xml.di.uminho.pt/PED2004/bibliografia" xmlns:prog="http://xml.di.uminho.pt/PED2004/programa" xmlns:txt="http://xml.di.uminho.pt/PED2004/texto" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:output method="xml" encoding="ISO-8859-1" omit-xml-declaration="no" indent="yes"/> 

	<xsl:template match="dos:mtodos">
		<xsl:variable name="m" select="count(dos:mtodo) "/>
		<xsl:choose>
			<xsl:when test="$m=1">
				<xsl:apply-templates select="dos:mtodo"/>
			</xsl:when>
			<xsl:otherwise>	
				<xsl:for-each select="dos:mtodo">
					<fo:block font-size="16pt" line-height="20pt" space-before.optimum="25pt" space-after.optimum="15pt" text-align="start" color="navy" font-weight="bold" keep-with-next="always">Mtodo <xsl:number format="A"/></fo:block>
					<xsl:apply-templates select="."/>
				</xsl:for-each>		
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="dos:mtodo">
		<xsl:variable name="numelem" select="count(dos:elementos-av/dos:elem-av)"/>
		<fo:block font-size="14pt" font-family="sans-serif" line-height="18pt" space-before.optimum="15pt" space-after.optimum="10pt" text-align="start"  color="navy" keep-with-next="always">Elemento<xsl:if test="$numelem &gt; 1">s</xsl:if> de avaliao</fo:block>
		<fo:block space-after.optimum="10pt">
			A avaliao da aprendizagem da disciplina  de tipo <xsl:value-of select="dos:tipo-avaliao"/>, envolvendo 
			<xsl:if test="$numelem=1">um s elemento de avaliao: </xsl:if>
			<xsl:if test="$numelem &gt; 1"><xsl:value-of select="$numelem"/> elementos de avaliao: </xsl:if>
		</fo:block>
		<fo:list-block provisional-distance-between-starts="7mm" provisional-label-separation="2mm" start-indent="2mm" space-before.optimum="4pt" space-after.optimum="4pt">
			<xsl:apply-templates select="dos:elementos-av/dos:elem-av"/>
		</fo:list-block>
		<fo:block font-size="14pt" font-family="sans-serif" line-height="18pt" space-before.optimum="15pt" space-after.optimum="10pt" text-align="start"  color="navy" keep-with-next="always">Frmula de avaliao</fo:block>
		<fo:block space-after.optimum="15pt">
			A classificao final <fo:inline font-weight="bold" font-style="italic"> nf </fo:inline>ser dada pela frmula :
		</fo:block> 
		<fo:block space-after.optimum="5pt" start-indent="8mm">
			<xsl:apply-templates select="dos:frmula"/>
		</fo:block>
		<xsl:if test="dos:resumo">
			<fo:block font-size="14pt" font-family="sans-serif" line-height="18pt" space-before.optimum="15pt" space-after.optimum="5pt" text-align="start"  color="navy" keep-with-next="always">Resumo</fo:block>
			<fo:block><xsl:apply-templates select="dos:resumo"/></fo:block>
		</xsl:if>
	</xsl:template>
		
	<xsl:template match="dos:resumo|dos:descrio">
		<xsl:apply-templates/>	
	</xsl:template>
	
	<xsl:template match="dos:elem-av">
		<fo:list-item space-after.optimum="5pt">
			<fo:list-item-label end-indent="label-end()">
				<fo:block font-weight="bold" vertical-align="sub"><xsl:number level="single" format="i) "/></fo:block>
			</fo:list-item-label>
			<fo:list-item-body start-indent="body-start()">
				<fo:block  font-size="12pt" font-family="sans-serif" line-height="15pt" space-before.optimum="6pt" space-after.optimum="6pt" text-align="start">
					<fo:block font-weight="bold" text-decoration="underline">
						<xsl:value-of select="dos:nome"/> (<fo:inline font-style="italic"><xsl:value-of select="dos:chave"/></fo:inline>)
					</fo:block>
					<fo:block margin-left="5pt">
						<xsl:if test="dos:descrio"><xsl:apply-templates select="dos:descrio"/></xsl:if>
					</fo:block>
				</fo:block>					
			</fo:list-item-body>	
		</fo:list-item>
	</xsl:template>
	
	<xsl:template match="dos:frmula">
		<xsl:variable name="c" select="dos:critrio"/>
		<xsl:if test="$c='Mximo'">Max(<xsl:call-template name="arg">
				<xsl:with-param name="comp" select="dos:componentes"/>
			</xsl:call-template>)
		</xsl:if>
		<xsl:if test="$c='Mnimo'">Min(<xsl:call-template name="arg">
				<xsl:with-param name="comp" select="dos:componentes"/>
			</xsl:call-template>)
		</xsl:if>
		<xsl:if test="$c='Somatrio'">
			<xsl:call-template name="soma">
				<xsl:with-param name="comp" select="dos:componentes"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="arg">
		<xsl:param name="comp" select="."/>
		<fo:inline font-weight="bold" font-style="italic"> nf </fo:inline>  =  
		<xsl:for-each select="$comp/dos:componente">
			<xsl:variable name="elem" select="key('i-elem',dos:elem-ref/@ref)/dos:chave"/>
			<xsl:value-of select="dos:peso"/> %  * <fo:inline font-weight="bold" font-style="italic"><xsl:value-of select="$elem"/></fo:inline><xsl:if test="following-sibling::dos:componente"> , </xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="soma">
		<xsl:param name="comp" select="."/>
		<fo:inline font-weight="bold" font-style="italic"> nf </fo:inline>  = 
		<xsl:for-each select="$comp/dos:componente">
			<xsl:variable name="elem" select="key('i-elem',dos:elem-ref/@ref)/dos:chave"/>
			<xsl:value-of select="dos:peso"/> %  * <fo:inline font-weight="bold" font-style="italic"><xsl:value-of select="$elem"/></fo:inline><xsl:if test="following-sibling::dos:componente"> + </xsl:if>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
